package org.zeroturnaround.javarebel.support;

import java.net.URL;
import org.zeroturnaround.javarebel.ClassResource;
import org.zeroturnaround.javarebel.support.JarResourceCache.JarCache;

public class JarClassResource implements ClassResource {
  private static final String RELOADABLE_SUFFIX = "-reloadable.jar";
  private JarCache cache;
  private final String entryName;
  private URL url;
  
  JarClassResource(JarCache cache, URL url, String entryName) {
    this.url = url;
    this.cache = cache;
    this.entryName = entryName;
  }

  public byte[] getBytes() {
    return cache.getEntryBytes(entryName);
  }

  public long lastModified() {
    return cache.getEntryLastModified(entryName);
  }
  
  public boolean isReloadable() {
    return cache.isManifestReloadable() || cache.getFile().getName().toLowerCase().endsWith(RELOADABLE_SUFFIX);    
  }
  
  public URL toURL() {
    return url;
  }
  
  public String toString() {
    return url.toString();
  }
}
